==> wasabiD-0.2.92.tgz: package/Base/Form/Select.jsx <==
/**
 * Created by zhiyongwang on 2016-03-30.
 * 下拉框
 */
require("../../sass/Base/Form/Select.scss");
let React=require("react");
let alogUtil=require("../../libs/alogUtil.js");
var FetchModel=require("../../model/FetchModel.js");
let Select=React.createClass({
    PropTypes:{
        name: React.PropTypes.string.isRequired,//对应表单name属性，用于提交
        label:React.PropTypes.string,//描述文字
        placeholder:React.PropTypes.string,//输入框内的提示文字
        valueField: React.PropTypes.string,//数据字段值名称
        textField:React.PropTypes.string,//数据字段文本名称
        value:React.PropTypes.string,//默认value值，
        text:React.PropTypes.string,//默认text值
        className:React.PropTypes.string,//附加新式
        readonly:React.PropTypes.bool,//是否只读,
        hide:React.PropTypes.hide,//是否隐藏 :
        url:React.PropTypes.string,//ajax的后台地址
        backSource:React.PropTypes.string,//ajax的返回的数据源中哪个属性作为数据源,为null时直接后台返回的数据作为数据源
        data:React.PropTypes.string,//数据源
        extraData:React.PropTypes.array,//额外的数据
        onSelect: React.PropTypes.func,//选中后的事件，回传，value,与text
        onClick: React.PropTypes.func,//自定义单击事件
    },
    getDefaultProps:function() {
            return{
                label:"",
                placeholder:"",
                valueField:"value",
                textField:"text",
                value:"",
                text:"",
                url:null,
                backSource:null,
                readonly:false,
                className:"",
                hide:false,
                data:[],
                extraData:[],
                onClick:null,
                onSelect:null
            };
        },
    getInitialState:function() {
        var newData=[];var text=this.props.text;
        for(let i=0;i<this.props.data.length;i++)
        {
            let obj={};
            obj.text=this.props.data[i][this.props.textField];
            obj.value=this.props.data[i][this.props.valueField];
            if(obj.value==this.props.value)
            {
                text=obj.text;//根据value赋值
            }
            newData.push(obj);
        }
            return {
                data:newData,
                value:this.props.value,
                text:text,
                ulShow:false,//是否显示下拉选项
            }
        },
    componentWillReceiveProps:function(nextProps) {
        if(nextProps.data!=null&&nextProps.data.length>0) {
            var newData=[];var text=nextProps.text;
            for(let i=0;i<nextProps.data.length;i++)
            {
                let obj={};
                obj.text=nextProps.data[i][this.props.textField];
                obj.value=nextProps.data[i][this.props.valueField];
                if(obj.value==nextProps.value)
                {
                    text=obj.text;//根据value赋值
                }
                newData.push(obj);
            }
            this.setState({
              data:newData,
                value: nextProps.value,
                text: text,
            })
        }
        else {
            this.setState({
                value: nextProps.value,
                text: nextProps.text,
            })
        }
    },
    componentWillMount:function() {//如果指定url,先查询数据再绑定
     if(this.props.url!=null)
     {
        var fetchmodel=new FetchModel(this.props.url,this.loadSuccess)
         alogUtil.fetch.get(fetchmodel);
     }
    },
    loadSuccess:function(data) {//数据加载成功
        var realData=data;
        if(this.props.backSource==null) {
        }
        else {
            realData=alogUtil.getSource(data,this.props.backSource);
        }
            var newData=[];var text=this.state.text;
            for(let i=0;i<realData.length;i++)
            {
                let obj={};
                obj.text=realData[i][this.props.textField];
                obj.value=realData[i][this.props.valueField];
                if(obj.value==this.state.value)
                {
                    text=obj.text;//根据value赋值
                }
                newData.push(obj);
            }
           if(this.props.extraData==null||this.props.extraData.length==0)
           {
               //没有额外的数据
           }
          else
           {
               //有额外的数据
               for(let i=0;i<this.props.extraData.length;i++)
               {
                   let obj={};
                   obj.text=this.props.extraData[i][this.props.textField];
                   obj.value=this.props.extraData[i][this.props.valueField];
                   if(obj.value==this.state.value)
                   {
                       text=obj.text;//根据value赋值
                   }
                   newData.unshift(obj);
               }
           }
            window.localStorage.setItem(this.props.name+'data' ,JSON.stringify(newData));//用于后期获取所有数据
            this.setState({
                data:newData,
                value:this.state.value,
                text:text,
            })
    },
    showItem:function() {//显示下拉选项
        if(this.props.readonly)
        {
            return ;
        }
            if(this.props.onClick!=null)
            {
                this.props.onClick();
            }
            else
            {
                this.setState({
                    ulShow: !this.state.ulShow
                })
            }
    },
    onSelect:function(value,text) {//选中事件
        if(value==undefined)
        {
            console.error("绑定的valueField没有")
        }
        if(text==undefined)
        {
            console.error("绑定的textField没有");
        }

        this.setState({
            ulShow:false,
            value:value,
            text:text,
        });

        if( this.props.onSelect!=null)
        {
          this.props.onSelect(value,text,this.props.name);
        }
    },
    changeHandler:function(event) {//一害绑定，但不处理

    },
    mouseOutHandler:function(event) {//鼠标移开时隐藏下拉
        if((event.relatedTarget==undefined||event.relatedTarget==null)||(event.relatedTarget.nodeName!="LI"&&event.relatedTarget.nodeName!="UL"&&event.relatedTarget.nodeName!="INPUT"))
        {
            this.setState({
                ulShow: false,
            });
        }

    },
    getComponentData:function() {//只读属性，获取对应的字段的数据源
        return this.state.data;
    },
    render:function() {
        let props=
        {
            readOnly:this.props.readonly==true?"readonly":null,
            style:this.props.style,
            name:this.props.name,
            placeholder:this.props.placeholder,
            className:"Form-control  "+(this.props.className!=""?this.props.className:"")

        }
        var control=null;
        if(this.state.data&&this.state.data.length>0) {


            control = <ul style={{display:this.state.ulShow==true?"block":"none"}} >
                {

                    this.state.data.map((child, i)=> {

                        return (
                            <li key={"li"+i}
                                onClick={this.onSelect.bind(this, child.value, child.text)}>{child.text}</li>
                        )
                    })

                }
            </ul>;
        }
        return (

            <div className="nice-select" style={{display:this.props.hide==true?"none":"block"}}   onMouseOut={this.mouseOutHandler} >
                <i className="icon" onClick={this.showItem}></i>
                <input type="text" {...props} value={this.state.text} onChange={this.changeHandler}  />

                {
                    control
                }
            </div>
        );

}

});
module.exports=Select;

==> wasabiD-0.2.983.tgz: package/Base/Form/Select.jsx <==
/**
 * Created by zhiyongwang on 2016-03-30.
 * 下拉框
 */
require("../../sass/Base/Form/Select.scss");
let React=require("react");
let unit=require("../../libs/unit.js");
var FetchModel=require("../../model/FetchModel.js");
let Select=React.createClass({
    PropTypes:{
        name: React.PropTypes.string.isRequired,//对应表单name属性，用于提交
        label:React.PropTypes.string,//描述文字
        placeholder:React.PropTypes.string,//输入框内的提示文字
        valueField: React.PropTypes.string,//数据字段值名称
        textField:React.PropTypes.string,//数据字段文本名称
        value:React.PropTypes.string,//默认value值，
        text:React.PropTypes.string,//默认text值
        className:React.PropTypes.string,//附加新式
        readonly:React.PropTypes.bool,//是否只读,
        hide:React.PropTypes.hide,//是否隐藏 :
        url:React.PropTypes.string,//ajax的后台地址
        backSource:React.PropTypes.string,//ajax的返回的数据源中哪个属性作为数据源,为null时直接后台返回的数据作为数据源
        data:React.PropTypes.string,//数据源
        extraData:React.PropTypes.array,//额外的数据
        onSelect: React.PropTypes.func,//选中后的事件，回传，value,与text
        onClick: React.PropTypes.func,//自定义单击事件
    },
    getDefaultProps:function() {
            return{
                label:"",
                placeholder:"",
                valueField:"value",
                textField:"text",
                value:"",
                text:"",
                url:null,
                backSource:null,
                readonly:false,
                className:"",
                hide:false,
                data:[],
                extraData:[],
                onClick:null,
                onSelect:null
            };
        },
    getInitialState:function() {
        var newData=[];var text=this.props.text;
        for(let i=0;i<this.props.data.length;i++)
        {
            let obj={};
            obj.text=this.props.data[i][this.props.textField];
            obj.value=this.props.data[i][this.props.valueField];
            if(obj.value==this.props.value)
            {
                text=obj.text;//根据value赋值
            }
            newData.push(obj);
        }
            return {
                data:newData,
                value:this.props.value,
                text:text,
                ulShow:false,//是否显示下拉选项
            }
        },
    componentWillReceiveProps:function(nextProps) {
        if(nextProps.data!=null&&nextProps.data.length>0) {
            var newData=[];var text=nextProps.text;
            for(let i=0;i<nextProps.data.length;i++)
            {
                let obj={};
                obj.text=nextProps.data[i][this.props.textField];
                obj.value=nextProps.data[i][this.props.valueField];
                if(obj.value==nextProps.value)
                {
                    text=obj.text;//根据value赋值
                }
                newData.push(obj);
            }
            this.setState({
              data:newData,
                value: nextProps.value,
                text: text,
            })
        }
        else {
            this.setState({
                value: nextProps.value,
                text: nextProps.text,
            })
        }
    },
    componentWillMount:function() {//如果指定url,先查询数据再绑定
     if(this.props.url!=null)
     {
        var fetchmodel=new FetchModel(this.props.url,this.loadSuccess)
         unit.fetch.get(fetchmodel);
     }
    },
    loadSuccess:function(data) {//数据加载成功
        var realData=data;
        if(this.props.backSource==null) {
        }
        else {
            realData=unit.getSource(data,this.props.backSource);
        }
            var newData=[];var text=this.state.text;
            for(let i=0;i<realData.length;i++)
            {
                let obj={};
                obj.text=realData[i][this.props.textField];
                obj.value=realData[i][this.props.valueField];
                if(obj.value==this.state.value)
                {
                    text=obj.text;//根据value赋值
                }
                newData.push(obj);
            }
           if(this.props.extraData==null||this.props.extraData.length==0)
           {
               //没有额外的数据
           }
          else
           {
               //有额外的数据
               for(let i=0;i<this.props.extraData.length;i++)
               {
                   let obj={};
                   obj.text=this.props.extraData[i][this.props.textField];
                   obj.value=this.props.extraData[i][this.props.valueField];
                   if(obj.value==this.state.value)
                   {
                       text=obj.text;//根据value赋值
                   }
                   newData.unshift(obj);
               }
           }
            window.localStorage.setItem(this.props.name+'data' ,JSON.stringify(newData));//用于后期获取所有数据
            this.setState({
                data:newData,
                value:this.state.value,
                text:text,
            })
    },
    showItem:function() {//显示下拉选项
        if(this.props.readonly)
        {
            return ;
        }
            if(this.props.onClick!=null)
            {
                this.props.onClick();
            }
            else
            {
                this.setState({
                    ulShow: !this.state.ulShow
                })
            }
    },
    onSelect:function(value,text) {//选中事件
        if(value==undefined)
        {
            console.error("绑定的valueField没有")
        }
        if(text==undefined)
        {
            console.error("绑定的textField没有");
        }

        this.setState({
            ulShow:false,
            value:value,
            text:text,
        });

        if( this.props.onSelect!=null)
        {
          this.props.onSelect(value,text,this.props.name);
        }
    },
    changeHandler:function(event) {//一害绑定，但不处理

    },
    mouseOutHandler:function(event) {//鼠标移开时隐藏下拉
        if((event.relatedTarget==undefined||event.relatedTarget==null)||(event.relatedTarget.nodeName!="LI"&&event.relatedTarget.nodeName!="UL"&&event.relatedTarget.nodeName!="INPUT"))
        {
            this.setState({
                ulShow: false,
            });
        }

    },
    getComponentData:function() {//只读属性，获取对应的字段的数据源
        return this.state.data;
    },
    render:function() {
        let props=
        {
            readOnly:this.props.readonly==true?"readonly":null,
            style:this.props.style,
            name:this.props.name,
            placeholder:this.props.placeholder,
            className:"Form-control  "+(this.props.className!=""?this.props.className:"")

        }
        var control=null;
        if(this.state.data&&this.state.data.length>0) {


            control = <ul style={{display:this.state.ulShow==true?"block":"none"}} >
                {

                    this.state.data.map((child, i)=> {

                        return (
                            <li key={"li"+i}
                                onClick={this.onSelect.bind(this, child.value, child.text)}>{child.text}</li>
                        )
                    })

                }
            </ul>;
        }
        return (

            <div className="nice-select" style={{display:this.props.hide==true?"none":"block"}}   onMouseOut={this.mouseOutHandler} >
                <i className="icon" onClick={this.showItem}></i>
                <input type="text" {...props} value={this.state.text} onChange={this.changeHandler}  />

                {
                    control
                }
            </div>
        );

}

});
module.exports=Select;
